@@ -9,7 +9,7 @@
 #   trustworthy does not get caught, but the evil cannot pass through."
 
 package Net::Gemini::Server;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use 5.10.0;
 # the below code mostly cargo culted from example/ssl_server.pl
 use IO::Socket::SSL;
@@ -86,7 +86,9 @@ sub withforks {
             $callback->( $client, $n, $buf );
             1;
         } or do {
-            warn "callback error: $@";
+            # KLUGE random stderr from a fork can confuse TAP and get
+            # the tests out of sequence?
+            #warn "callback error: $@";
             close $client;
         };
         exit;
